@@ -3,11 +3,8 @@
 
 #include <QObject>
 #include <syncer.h>
-#ifdef STATIC_MAUIKIT
-#include "fmh.h"
-#else
-#include <MauiKit/fmh.h>
-#endif
+
+#include <MauiKit/Core/fmh.h>
 
 /**
  * @brief The Syncer class
